@@ -35,6 +35,12 @@ FAILEDOPERATION_CRUNSUPPORTMETHOD = 'FailedOperation.CRUnsupportMethod'
 # 房间中没有设置混流模板。
 FAILEDOPERATION_MIXSESSIONNOTEXIST = 'FailedOperation.MixSessionNotExist'
 
+# 未开通RTMP
+FAILEDOPERATION_NOTRTMPFUNCTION = 'FailedOperation.NotRtmpFunction'
+
+# 查询任务失败
+FAILEDOPERATION_QUERYTASKINFOFAILED = 'FailedOperation.QueryTaskInfoFailed'
+
 # 云API混流模板和SDK混流冲突。
 FAILEDOPERATION_REQUESTREJECTION = 'FailedOperation.RequestRejection'
 
@@ -47,6 +53,12 @@ FAILEDOPERATION_ROOMNOTEXIST = 'FailedOperation.RoomNotExist'
 # 应用ID不存在。
 FAILEDOPERATION_SDKAPPIDNOTEXIST = 'FailedOperation.SdkAppIdNotExist'
 
+# 任务已存在
+FAILEDOPERATION_TASKEXIST = 'FailedOperation.TaskExist'
+
+# 调用接口时任务已结束。
+FAILEDOPERATION_TASKFINISHED = 'FailedOperation.TaskFinished'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -68,6 +80,9 @@ INTERNALERROR_GETROOMFROMCACHEERROR = 'InternalError.GetRoomFromCacheError'
 # http请求解析失败。
 INTERNALERROR_HTTPPARASEFALIED = 'InternalError.HttpParaseFalied'
 
+# http请求解析失败。
+INTERNALERROR_HTTPPARSEFAILED = 'InternalError.HttpParseFailed'
+
 # 接口错误。
 INTERNALERROR_INTERFACEERR = 'InternalError.InterfaceErr'
 
@@ -176,6 +191,9 @@ INVALIDPARAMETER_STRROOMID = 'InvalidParameter.StrRoomId'
 # StreamId参数错误。
 INVALIDPARAMETER_STREAMID = 'InvalidParameter.StreamId'
 
+# TaskId 参数错误。
+INVALIDPARAMETER_TASKID = 'InvalidParameter.TaskId'
+
 # Url解析参数失败。
 INVALIDPARAMETER_URLPARAMSERROR = 'InvalidParameter.UrlParamsError'
 
@@ -188,6 +206,9 @@ INVALIDPARAMETER_USERIDS = 'InvalidParameter.UserIds'
 # 用户数超过6个。
 INVALIDPARAMETER_USERIDSMORETHANSIX = 'InvalidParameter.UserIdsMorethanSix'
 
+# UserSig过期或错误。
+INVALIDPARAMETER_USERSIG = 'InvalidParameter.UserSig'
+
 # 视频分辨率参数错误。
 INVALIDPARAMETER_VIDEORESOLUTION = 'InvalidParameter.VideoResolution'
 
